@@ -130,11 +130,11 @@ class AudioStream(MediaStream):
         """
         Use ffmpeg with astats filter to get the mean (RMS) and max (peak) volume of the input file.
         """
-        logger.info(
-            f"Running first pass astats filter for stream {self.stream_id}"
-        )
+        logger.info(f"Running first pass astats filter for stream {self.stream_id}")
 
-        filter_str = self._get_filter_str_with_pre_filter("astats=measure_overall=Peak_level+RMS_level:measure_perchannel=0")
+        filter_str = self._get_filter_str_with_pre_filter(
+            "astats=measure_overall=Peak_level+RMS_level:measure_perchannel=0"
+        )
 
         cmd = [
             self.media_file.ffmpeg_normalize.ffmpeg_exe,
@@ -156,7 +156,9 @@ class AudioStream(MediaStream):
             yield progress
         output = cmd_runner.get_output()
 
-        logger.debug(f"astats command output: {CommandRunner.prune_ffmpeg_progress_from_output(output)}")
+        logger.debug(
+            f"astats command output: {CommandRunner.prune_ffmpeg_progress_from_output(output)}"
+        )
 
         mean_volume_matches = re.findall(r"RMS level dB: ([\-\d\.]+)", output)
         if mean_volume_matches:
@@ -221,7 +223,9 @@ class AudioStream(MediaStream):
             yield progress
         output = cmd_runner.get_output()
 
-        logger.debug(f"Loudnorm first pass command output: {CommandRunner.prune_ffmpeg_progress_from_output(output)}")
+        logger.debug(
+            f"Loudnorm first pass command output: {CommandRunner.prune_ffmpeg_progress_from_output(output)}"
+        )
 
         output_lines = [line.strip() for line in output.split("\n")]
 
@@ -289,15 +293,37 @@ class AudioStream(MediaStream):
                 "First pass not run, you must call parse_loudnorm_stats first"
             )
 
-        input_i = float(self.loudness_statistics["ebu"]["input_i"])
-        if input_i > 0:
+        if float(self.loudness_statistics["ebu"]["input_i"]) > 0:
             logger.warn(
-                "Input file had measured input loudness greater than zero ({}), capping at 0".format(
-                    "input_i"
-                )
+                f"Input file had measured input loudness greater than zero ({self.loudness_statistics['ebu']['input_i']}), capping at 0"
             )
             self.loudness_statistics["ebu"]["input_i"] = 0
 
+        will_use_dynamic_mode = self.media_file.ffmpeg_normalize.dynamic
+
+        if self.media_file.ffmpeg_normalize.keep_loudness_range_target:
+            logger.debug("Keeping target loudness range in second pass loudnorm filter")
+            self.media_file.ffmpeg_normalize.loudness_range_target = (
+                self.loudness_statistics["ebu"]["input_lra"]
+            )
+
+        if (
+            self.media_file.ffmpeg_normalize.loudness_range_target
+            < self.loudness_statistics["ebu"]["input_lra"]
+        ):
+            logger.warn(
+                f"Input file had loudness range of {self.loudness_statistics['ebu']['input_lra']}, which is larger than the loudness range target ({self.media_file.ffmpeg_normalize.loudness_range_target}). "
+                "Normalization will revert to dynamic mode. Choose a higher target loudness range if you want linear normalization. "
+                "Alternatively, use the --keep-loudness-range-target option to keep the target loudness range from the input."
+            )
+            will_use_dynamic_mode = True
+
+        if will_use_dynamic_mode and not self.ffmpeg_normalize.sample_rate:
+            logger.warn(
+                "In dynamic mode, the sample rate will automatically be set to 192 kHz by the loudnorm filter. "
+                "Specify -ar/--sample-rate to override it."
+            )
+
         opts = {
             "i": self.media_file.ffmpeg_normalize.target_level,
             "lra": self.media_file.ffmpeg_normalize.loudness_range_target,
@@ -307,7 +333,7 @@ class AudioStream(MediaStream):
             "measured_lra": float(self.loudness_statistics["ebu"]["input_lra"]),
             "measured_tp": float(self.loudness_statistics["ebu"]["input_tp"]),
             "measured_thresh": float(self.loudness_statistics["ebu"]["input_thresh"]),
-            "linear": "true",
+            "linear": "false" if self.media_file.ffmpeg_normalize.dynamic else "true",
             "print_format": "json",
         }
 
